Bug#586953: Reopen Bug#586953

Vladimir 'φ-coder/phcoder' Serbinenko phcoder at gmail.com
Tue Jul 20 12:56:58 UTC 2010


On 07/11/2010 09:58 PM, Jörg Sommer wrote:
> grub2 (1.98+20100705-1) unstable; urgency=medium
>>  .
>>    * New Bazaar snapshot.
>>      - Bidi and diacritics support.
>>        + Use terminfo for ieee1275 terminals (closes: #586953).
>>     
> I'm sorry, but this doesn't fix my problem. I've installed and run this
> new release, but I still have the problem that the commandline or editing
> mode is left, when I hold down an arrow key.
>
>   
I think that for some reason your ieee1275 is slower than the nominal
9600. Try following patch:
=== modified file 'term/terminfo.c'
--- term/terminfo.c    2010-05-09 11:26:52 +0000
+++ term/terminfo.c    2010-07-20 12:55:33 +0000
@@ -368,11 +368,11 @@
 #define CONTINUE_READ                        \
   {                                \
     grub_uint64_t start;                    \
     /* On 9600 we have to wait up to 12 milliseconds.  */    \
     start = grub_get_time_ms ();                \
     do                                \
       c = readkey ();                        \
-    while (c == -1 && grub_get_time_ms () - start < 12);    \
+    while (c == -1 && grub_get_time_ms () - start < 100);    \
     if (c == -1)                        \
       return;                            \
                                 \
@@ -368,11 +368,11 @@
   {                                \
     grub_uint64_t start;                    \
-    /* On 9600 we have to wait up to 12 milliseconds.  */    \
+    /* On 9600 we have to wait up to 100 milliseconds.  */    \
     start = grub_get_time_ms ();                \
     do                                \

-- 
Regards
Vladimir 'φ-coder/phcoder' Serbinenko


-------------- next part --------------
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 294 bytes
Desc: OpenPGP digital signature
URL: <http://lists.alioth.debian.org/pipermail/pkg-grub-devel/attachments/20100720/41fcfadd/attachment.pgp>


More information about the Pkg-grub-devel mailing list